@@ -4,6 +4,7 @@ import os, socket
 
 from coverage.annotate import AnnotateReporter
 from coverage.codeunit import code_unit_factory
+from coverage.collector import Collector
 from coverage.data import CoverageData
 from coverage.files import FileLocator
 from coverage.html import HtmlReporter
@@ -42,7 +43,6 @@ class coverage:
         measurement stops.
         
         """
-        from coverage.collector import Collector
         from coverage import __version__
         
         self.cover_pylib = cover_pylib
@@ -65,7 +65,8 @@ class coverage:
 
         self.data = CoverageData(
             basename=data_file, suffix=data_suffix,
-            collector="coverage v%s" % __version__)
+            collector="coverage v%s" % __version__
+            )
 
         # The default exclude pattern.
         self.exclude('# *pragma[: ]*[nN][oO] *[cC][oO][vV][eE][rR]')
@@ -75,6 +76,9 @@ class coverage:
             os_file = self.file_locator.canonical_filename(os.__file__)
             self.pylib_prefix = os.path.split(os_file)[0]
 
+        here = self.file_locator.canonical_filename(__file__)
+        self.cover_prefix = os.path.split(here)[0]
+
     def _should_trace(self, filename, frame):
         """Decide whether to trace execution in `filename`
         
@@ -107,7 +111,12 @@ class coverage:
         if not self.cover_pylib:
             if canonical.startswith(self.pylib_prefix):
                 return False
-        
+
+        # We exclude the coverage code itself, since a little of it will be
+        # measured otherwise.
+        if canonical.startswith(self.cover_prefix):
+            return False
+
         return canonical
 
     def use_cache(self, usecache):
