@@ -3,6 +3,9 @@
 import os
 import cPickle as pickle
 
+from coverage.backward import sorted    # pylint: disable-msg=W0622
+
+
 class CoverageData:
     """Manages collected coverage data, including file storage.
     
@@ -10,7 +13,8 @@ class CoverageData:
     
         * collector: a string identifying the collecting software
 
-        * lines: a dict mapping filenames to lists of line numbers executed:
+        * lines: a dict mapping filenames to sorted lists of line numbers
+          executed:
             { 'file1': [17,23,45],  'file2': [1,2,3], ... }
     
     """
@@ -87,15 +91,19 @@ class CoverageData:
                 os.remove(self.filename)
         self.lines = {}
         
+    def line_data(self):
+        """Return the map from filenames to lists of line numbers executed."""
+        return dict(
+            [(f, sorted(linemap.keys())) for f, linemap in self.lines.items()]
+            )
+
     def write_file(self, filename):
         """Write the coverage data to `filename`."""
 
         # Create the file data.        
         data = {}
 
-        data['lines'] = dict(
-            [(f, list(linemap.keys())) for f, linemap in self.lines.items()]
-            )
+        data['lines'] = self.line_data()
 
         if self.collector:
             data['collector'] = self.collector
@@ -109,12 +117,10 @@ class CoverageData:
 
     def read_file(self, filename):
         """Read the coverage data from `filename`."""
-        
         self.lines = self._read_file(filename)
 
     def _read_file(self, filename):
-        """ Return the stored coverage data from the given file.
-        """
+        """Return the stored coverage data from the given file."""
         try:
             fdata = open(filename, 'rb')
             try:
@@ -164,6 +170,7 @@ class CoverageData:
         
         If `filename` hasn't been collected at all (because it wasn't executed)
         then return an empty map.
+
         """
         return self.lines.get(filename) or {}
 
